@@ -42,6 +42,13 @@ msword = r'''<b:Source xmlns:b="http://schemas.microsoft.com/office/'''\
 <b:Publisher>$Publisher</b:Publisher>
 </b:Source>'''
 
+json = r'''{"type": "book",
+"title": "$Title",
+"author": [$AUTHORS],
+"year": "$Year",
+"identifier": [{"type": "ISBN", "id": "$ISBN"}],
+"publisher": "$Publisher"}'''
+
 labels = r"""Type:      BOOK
 Title:     $Title
 Author:    $AUTHORS
@@ -51,7 +58,7 @@ Publisher: $Publisher"""
 
 templates = {'labels': labels, 'bibtex': bibtex,
              'endnote': endnote, 'refworks': refworks,
-             'msword': msword}
+             'msword': msword, 'json': json}
 
 fmts = templates.keys()
 
@@ -79,8 +86,7 @@ def _spec_proc(name, fmtrec, authors):
     """
     Fixes the Authors records (TODO: refator this!)
     """
-    if name not in ('labels', 'bibtex',
-                    'refworks', 'endnote', 'msword'):
+    if name not in fmts:
         return
     if name == 'labels':
         AUTHORS = '\nAuthor:    '.join(authors)
@@ -91,14 +97,15 @@ def _spec_proc(name, fmtrec, authors):
     if name == 'endnote':
         AUTHORS = '\n%A '.join(authors)
     if name == 'msword':
-        uid = str(uuid.uuid4())
-        fmtrec = Template(fmtrec).safe_substitute(uid=uid)
-        person = r"\n<b:Person><b:Last>$last</b:Last>"\
+        fmtrec = fmtrec.replace('$uid', str(uuid.uuid4()))
+        person = r"<b:Person><b:Last>$last</b:Last>"\
                  r"<b:First>$first</b:First></b:Person>"
-        AUTHORS = ''
-        for a in authors:
-            AUTHORS += Template(person).safe_substitute(_last_first(a))
-
+        AUTHORS = '\n'.join(
+            Template(person).safe_substitute(_last_first(a))
+            for a in authors)
+    if name == 'json':
+        AUTHORS = ', '.join('{"name": "$"}'.replace("$", a)
+                            for a in authors)
     return re.sub(r'\$AUTHORS', AUTHORS, fmtrec)
 
 
