@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
+"""
+Private helper functions
+"""
 
 import re
+import functools
 
 
 def normalize_space(item):
@@ -22,3 +26,12 @@ def titlecase(s):
     """
     return re.sub(r"[A-Za-z]+('[A-Za-z]+)?",
                   lambda m: m.group(0)[0].upper() + m.group(0)[1:], s)
+
+
+def compose1arg(*functions):
+    """
+    Composes one-argument functions
+
+    Very handy for functional techniques!
+    """
+    return functools.reduce(lambda f, g: lambda x: f(g(x)), functions)
